clear all;
close all;

% Parametry simulace
t0 = 0;  % Zacatek simulace
tn = 1;  % Konec simulace
h = 0.0001;  % Velikost kroku simulace

% Parametry simulovaneho procesu
k1 = 100;  % Zesileni aperiodického bloku 1      
k2 = 100;  % Zesileni aperiodického bloku 2 
tau1 = 0.01;  % Casova konstanta aperiodickeho bloku 1
tau2 = 1;  % Casova konstanta aperiodickeho bloku 2

% Nastaveni PI regulatoru, pro P klasicky K_p, pro I klasicky K_i
% My mame K_p = K_r a K_i = K_r/tau_r 
kr = 0.01;  % Zesileni proporcinalniho regulatoru 
taur = 0.066;  % Casova konstanta integracniho regulatoru (inf = potlaceni)

% Pocatecni hodnoty
ui0 = 0;  % vystup z integracniho regulatoru  
x0 = 0;  % vystup z bloku 1
y0 = 0;  % vystup z bloku 2 - regulovaná velicina

% Pocatecni hodnota stavoveho vektoru x (mame dve xka, bacha)
xstate0 = ...;

% Parametry maticoveho zapisu modelu
A = ...;
q = ...;
r = ...;

% Definice integrovane funkce s odpovidajici signaturou
odefun = @(t,x) ...;

% Vlastni integrace pomoci RK4 s automatickou volbou velikosti kroku a 
% pomoci dopredneho Eulerova pravidla s pevnym krokem h
tic;
[t,xstate] = ode45(...);
time_ode45 = toc();  % Doba vypoctu ODE45
tic;
[te,xstatee] = ode1(...);
time_ode1 = toc();  % Doba vypocty ODE1

% Pro vykreslovaci ucely potrebujeme hodnoty w(t) a z(t) v casech, kdy
% mame spocitana reseni ode45.
w = ...;
z = ...;
y = ...;  % ode45
ye = ...;  % ode1

%
% Graf #1: Pozadavek w(t), porucha z(t) a vystup y(t)
%
f1 = figure(1);
% Abychom mohli nasyavit parametry car, nechame plot() vratit vlastnosti 
% jednotlivych LineSeries objektu grafu  
lx = plot(t, [...]);  % Pozadavek, pozadavek+40%, vystup
lx(2).LineStyle = '--';  % Pozadavek+40% carkovane
lx(3).LineWidth = 2;  % Vystup carou dvojnasobne tloustky
%
xlim([-0.01, 1]);
ylim([-0.02, 1.5]);
ylabel('Pozadavek u(t) a vystup y(t)');
% 
yyaxis right;  % Do toho sameho obrazku s jinym meritkem, osa y vpravo
%
plot(t,...);  % Porucha
ylim([-0.0029, 0.21]);  % Cca souhlasi 0, neni ale urceno presne
ylabel('Porucha z(t)');
%
legend('w','w+40%','y', 'z', 'Location', 'southeast');
grid on;
xlabel('t');

%
% Graf #2: Porovnani ode45 a ode1, velikost kroku ode45, odchylky
%
f2 = figure(2);
%
% Napred ode45 a ode1, velikost kroku ode45
%
subplot(3,1,[1 2]);  % 2/3 zabira tento graf
%
plot(t, ..., te, ...);
xlabel('t');
ylabel('y(t)');
%
yyaxis('right');
% Spocteme si delky kroku ...
hk = t(2:end)-t(1:end-1);  %
% bude jich o 1 mene nez puvodnich vzorku
tx = t(1:end-1);
plot(tx, hk, '--k');
ylabel('Délka h_k');
%
legend('ode45', 'ode1', 'Location', 'southeast');
% A protoze Matlab popis druhé y osy obarvi, musime natvrdo nastavit cernou
f2.CurrentAxes.YAxis(2).Color = [0 0 0];
%
% A ted odchylky do dalsiho subplotu
%
subplot(3,1,3);
% Napred musime prevzorkovat t,y na hodnoty te,y_interpolovane
yinterp = interp1(t, y, te);
% Ted muzeme spocitat absolutni chybu
abserr = ...;
% A konecne muzeme vykreslit
semilogy(te, abserr);
xlabel('t');
ylabel('A(y)');



